DfSettings class

  • decoration: Optional custom BoxDecoration for styling the container.
  • containerHeight: Optional height for the dialog container. Defaults to 140.
  • containerWidth: Optional width for the dialog container. Defaults to 200.
  • customBody: Custom widget that can replace the default loading dialog content.
  • loadingIndicator: Optional widget for a loading indicator. Defaults to CircularProgressIndicator.
  • textStyle: Optional text style for the message inside the dialog.

Properties

containerHeight ↔ double?
containerHeight: Optional height for the dialog container. Defaults to 140.
getter/setter pair
containerWidth ↔ double?
Optional width for the dialog container. Defaults to 200.
getter/setter pair
customBody ↔ Widget?
Custom widget that can replace the default loading dialog content.
getter/setter pair
decoration ↔ BoxDecoration?
Optional custom BoxDecoration for styling the container.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
loadingIndicator ↔ Widget?
Optional widget for a loading indicator. Defaults to CircularProgressIndicator.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textStyle ↔ TextStyle?
Optional text style for the message inside the dialog.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

getInstance() → DfSettings